#
# spec file for package asymptote
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with lsp
Name:           asymptote
Version:        3.01
Release:        1.1
Summary:        2D & 3D TeX-Aware vector graphics language
License:        LGPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://asymptote.sourceforge.io/
#Git-Clone:     https://github.com/vectorgraphics/asymptote
Source:         https://github.com/vectorgraphics/asymptote/archive/refs/tags/%version.tar.gz
#NEWS:          https://asymptote.sourceforge.io/ReleaseNotes
Patch1:         use-system-libs.patch
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc-c++
%if %{with lsp}
BuildRequires:  libboost_chrono-devel
BuildRequires:  libboost_date_time-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
%endif
BuildRequires:  makeinfo
BuildRequires:  ncurses-devel
BuildRequires:  python-rpm-macros
BuildRequires:  readline-devel
BuildRequires:  texinfo
BuildRequires:  texlive-dvips-bin
BuildRequires:  texlive-kpathsea-bin
BuildRequires:  texlive-latex-bin-bin
BuildRequires:  xz
BuildRequires:  pkgconfig(bdw-gc)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glm)
BuildRequires:  pkgconfig(glut)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(libglvnd)
BuildRequires:  pkgconfig(libtirpc)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  tex(media9.sty)
BuildRequires:  tex(parskip.sty)
BuildRequires:  tex(type1cm.sty)
Conflicts:      texlive-asymptote
Conflicts:      texlive-asymptote-bin
Conflicts:      texlive-asymptote-doc

%description
Asymptote is a descriptive vector graphics language for technical
drawing, inspired by MetaPost, but with a C++-like syntax. Asymptote
provides for figures the same quality of typesetting that LaTeX does
for scientific text.

%prep
%autosetup
rm -Rfv libatomic_ops gc

%build
if [ ! -e configure ]; then autoreconf -fiv; fi
%configure --with-docdir="%_docdir/%name"
%make_build

%install
%make_install
mv "%buildroot/usr/local/share"/* "%buildroot/%_datadir/"
chmod a-x "%buildroot/%_datadir/asymptote/shaders"/*.glsl
find "%buildroot/%_datadir/asymptote/GUI" -type f -name "*.py" \
	-exec perl -i -lpe "s{^#!/usr/bin/env python3}{#!/usr/bin/python%python3_bin_suffix}g" {} +

%files
%_bindir/asy
%_bindir/xasy
%_datadir/%name/
%_datadir/texmf/
%_docdir/%name/
%_infodir/asy*
%_mandir/*/*asy.1*
%license LICENSE*

%changelog
* Fri Mar 14 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.01
  * A floating point exception was fixed.
* Thu Feb 13 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.99
  * Build system updates only
* Sun Feb  9 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.97
  * By default, orthographic projections now use ``center=true``;
    the camera and target are automatically centered within the
    scene.
  * Triangle groups are used for indexed surfaces drawn with the
    render option tessellate=true.
  * GLSL error reporting was restored.
  * New keywords ``autounravel`` and ``using`` were added.
- Add use-system-libs.patch
* Thu Jul 18 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.90
  * Support templated access with imported and top-level
    structure types, templated access with types containing
    static fields, and templated imports for parameter types
    defined in imported modules.
  * Decouple scaling of each dimension with a fixed version of
    the original 2-variable simplex method.
  * Fix approximate transparency rendering for GPUs without SSBO
    support.
* Thu Jun 13 2024 Markéta Machová <mmachova@suse.com>
- Drop the dependency on /usr/bin/python3 symlink
  * boo#1212476
* Thu Apr 11 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.89
  * Avoid broken dvisvgm reassign-clippaths optimization.
  * Use a unique signature hash for identifying templated imports.
  * Optimize dvisvgm output by default.
- Delete 0001-Fix-without-lsp-issue-379.patch (merged)
* Sat Jun 24 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.86
  * Terminate phase1 of simplex method once a zero-cost solution
    is found.
  * Fix bug in XDR reads due to uninitialized variable.
  * Add high-resolution clock; update FFT support.
- Add 0001-Fix-without-lsp-issue-379.patch
* Sat Nov 19 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.83
  * WebGL triangle groups were fixed.
  * Context menus were added to Xasy objects to allow one to edit
    the fill type, line type, color, line cap, and optionally add
    arrowheads.
  * Support for begingroup() and endgroup() was added to Xasy.
  * Scaling in the vectorfield function was fixed.
  * A quotient(x,y) bug when -1 < x/y < 0, introduced in version
    2.42, was fixed.
* Wed Aug 10 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.82
  * Support for Ghostscript 9.56 was added.
  * The dvisvgmMultipleFiles option is now enabled by default.
  * The mean color of multicoloured patches is output only for
    PRC code.
  * Subdivision crack adjustments were disabled for transparent
    patches.
  * The OpenGL transparency shader was further accelerated.
* Thu Jun 16 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.81
  * Schur decompositions were implemented. A bug in uniform() was
    fixed.
  * The Xasy bounding box and a crash when opening Xasy files
    were fixed.
  * The transparency offset buffer is zeroed when GPU compression
    is unavailable.
  * The surface constructor for solids of revolution was
    documented.
  * Opaque rendering on platforms lacking
    GL_ARB_fragment_shader_interlock was fixed.
* Thu Apr 21 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.80
  * Compression of empty transparent pixel counts and other
    optimizations were implemented in the transparency shader. A
    weighted least-squares fit was added.
  * LSP: Add basic Language Server Protocol. server code to
    Asymptote.
  * Add preliminary v3d standard.
* Fri May  7 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.70
  * Fix segmentation fault in subpath3
  * Make Gouraud image respect x and y picture scaling
* Thu Dec 24 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.68
  * Floating point exceptions in OpenGL libraries are now masked.
  * A normalization used to render tubes was fixed.
  * A Label align(Label,dir) function was added for aligning
    label normals.
  * A new settings.compress=true option controls PDF image
    compression.
  * A bool isometry(transform) function was added.
  * The transpose function ignores uninitialized elements.
  * Null fields are treated as undefined values in cvs mode and
    in line mode.
  * Uninitialized rendering variables were fixed.
  * Logarithmic graphs of surfaces are supported.
  * Files are opened without assuming an asy suffix.
  * Support for Ghostscript 9.53 was implemented.
  * The end argument of Margin functions is now optional.
  * A function cputime().change.clock that returns the
    high-resolution elapsed wall clock time was added.
  * The centering of slides was fixed.
  * Null characters and null strings are supported in the replace
    function.
* Sun Aug 30 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.67:
  * Support was added for importing and inputting URLs.
  * Compilation and 2D SVG to HTML conversion no longer requires
    the GLM library; 2D html output is fit to the canvas unless
    settings.absolute=true.
  * Diagnostics for dvisvgm were enabled; SVG clipping was fixed.
  * A -globalread setting (default true) was implemented.
  * Files are opened using the search path, which now includes the
    examples directory.
  * An invalid array dimensions error was fixed.
  * A WebGL resize event listener was added; the + and - keys now
    zoom in and out, rather than expanding and shrinking the
    viewport.
  * Remeshing on export is forced; unnecessary remeshing on zoom
    in AsyGL is avoided.
  * The triple dir(path3, path3) function was normalized.
  * The repositioning of OpenGL windows was fixed.
  * The copy constructors for path and path3 were fixed.
  * Asymptote errors no longer cause Xasy to hang.
  * A numerical precision issue was fixed.
  * A portable way of skipping whitespace was implemented; casts
    from empty strings now yield uninitialized values.
  * Interrupt handling under MacOS X was fixed.
  * A devicepixelratio setting was implemented.
  * The error location is displayed in the console.
  * Segmentation faults were fixed.
  * The documentation was updated and the code was reformatted.
  * Obsolete encoding modules were removed.
* Thu Jun  4 2020 Jan Engelhardt <jengelh@inai.de>
- Add Conflicts towards texlive-asymptote.
* Wed Jun  3 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.65
  * A bug in rendering 2D preview images of a 3D scene was fixed.
    The 100-error TeX limit is gracefully detected, rather than
    hanging. A more accurate Bezier approximation to the sphere
    was implemented. An initial perpendicular direction can now
    be specified for the rotation minimizing frame for a path3;
    the previous direction is no longer cached between calls.
* Thu Mar  5 2020 Jan Engelhardt <jengelh@inai.de>
- Initial package (version 2.64) for build.opensuse.org
